@@ -1,14 +1,18 @@
 """System Bridge GUI: System Tray"""
 from __future__ import annotations
 
-import os
 from collections.abc import Callable
+import os
+from typing import Optional
 from webbrowser import open_new_tab
 
 from PySide6.QtGui import QAction, QCursor, QIcon
-from PySide6.QtWidgets import QMenu, QSystemTrayIcon, QWidget
+from PySide6.QtWidgets import QApplication, QMenu, QSystemTrayIcon
+from pyperclip import copy
 from systembridgeshared.base import Base
 from systembridgeshared.common import get_user_data_directory
+from systembridgeshared.database import Database
+from systembridgeshared.settings import Settings
 
 PATH_BRIDGES_OPEN_ON = "/app/bridges/openon.html"
 PATH_BRIDGES_SETUP = "/app/bridges/setup.html"
@@ -27,15 +31,20 @@ class SystemTray(Base, QSystemTrayIcon):
     # pylint: disable=unsubscriptable-object
     def __init__(
         self,
+        database: Database,
+        settings: Settings,
         icon: QIcon,
-        parent: QWidget,
+        parent: QApplication,
         callback_exit_application: Callable,
-        callback_show_window: Callable[[str, bool, int | None, int | None], None],
+        callback_show_window: Callable[[str, bool, Optional[int], Optional[int]], None],
     ) -> None:
         """Initialize the system tray"""
         Base.__init__(self)
         QSystemTrayIcon.__init__(self, icon, parent)
 
+        self._database = database
+        self._settings = settings
+
         self._logger.info("Setup system tray")
 
         self.callback_show_window = callback_show_window
@@ -61,33 +70,25 @@ class SystemTray(Base, QSystemTrayIcon):
         menu.addSeparator()
 
         latest_version_text = "Latest Version"
-        # if (
-        #     information is not None
-        #     and information.attributes is not None
-        #     and information.updates is not None
-        #     and information.updates.attributes is not None
-        # ):
-        #     if (
-        #         information.updates.available is not None
-        #         and information.updates.available
-        #     ):
-        #         latest_version_text = f"""Version {
-        #                 information.updates.version.new
-        #             } avaliable! ({
-        #                 information.updates.version.current
-        #             } -> {
-        #                 information.updates.version.new
-        #             })"""
-        #     elif information.updates.newer:
-        #         latest_version_text = f"""Version Newer ({
-        #                 information.updates.version.current
-        #             } > {
-        #                 information.updates.version.new
-        #             })"""
-        #     else:
-        #         latest_version_text = f"""Latest Version ({
-        #                 information.updates.version.current
-        #             })"""
+        version_current = self._database.read_table_by_key("system", "version").to_dict(
+            orient="records"
+        )[0]["value"]
+        version_latest = self._database.read_table_by_key(
+            "system", "version_latest"
+        ).to_dict(orient="records")[0]["value"]
+        record_version_newer_available = self._database.read_table_by_key(
+            "system", "version_newer_available"
+        )
+        version_newer_available = (
+            record_version_newer_available.to_dict(orient="records")[0]["value"]
+            if not record_version_newer_available.empty
+            else "False"
+        )
+
+        if version_newer_available.lower() == "true":
+            latest_version_text = f"{version_latest} (New)"
+        else:
+            latest_version_text += f" ({version_current})"
 
         action_latest_release: QAction = menu.addAction(latest_version_text)
         action_latest_release.triggered.connect(self._open_latest_releases)  # type: ignore
@@ -108,6 +109,11 @@ class SystemTray(Base, QSystemTrayIcon):
 
         menu_help.addSeparator()
 
+        action_api_key: QAction = menu_help.addAction("Copy API key to clipboard")
+        action_api_key.triggered.connect(self._copy_api_key)  # type: ignore
+
+        menu_help.addSeparator()
+
         action_log: QAction = menu_help.addAction("Open Log File")
         action_log.triggered.connect(self._open_log)  # type: ignore
 
@@ -117,7 +123,7 @@ class SystemTray(Base, QSystemTrayIcon):
         menu.addSeparator()
 
         action_exit: QAction = menu.addAction("Exit")
-        action_exit.triggered.connect(lambda: callback_exit_application(False))  # type: ignore
+        action_exit.triggered.connect(callback_exit_application)  # type: ignore
 
         self.setContextMenu(menu)
 
@@ -129,6 +135,12 @@ class SystemTray(Base, QSystemTrayIcon):
         if reason == QSystemTrayIcon.Trigger:
             self.contextMenu().popup(QCursor.pos())
 
+    def _copy_api_key(self) -> None:
+        """Copy API key to clipboard"""
+        self._logger.info("Copy API key to clipboard")
+        key = self._settings.get_secret("api_key")
+        copy(key)
+
     def _open_latest_releases(self) -> None:
         """Open latest release"""
         self._logger.info("Open: %s", URL_LATEST_RELEASE)
